<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Environnement live détecté. Choisissez la partition racine du système que vous souhaitez modifier (seules les partitions Linux sont affichées)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Kernel parameters</source>
        <translation>Paramètres du noyau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Régler sur &apos;0&apos; pour démarrer immédiatement sans afficher le menu, ou sur &apos;-1&apos; pour attendre indéfiniment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Menu timeout</source>
        <translation>Durée du menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="75"/>
        <source>Boot to</source>
        <translation>Démarrer sur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Utiliser une interface simple de menu sans sous-menus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Utiliser menus plats (pas de sous-menus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>En activant cette option, l&apos;entrée choisie depuis le menu de démarrage grub sera sauvegardée et activée par défaut pour les prochains démarrages</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Enable saving last boot choice</source>
        <translation>Activer la sauvegarde du dernier choix de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Enable theme</source>
        <translation>Activer le thème</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Splash</source>
        <translation>Écran d&apos;accueil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>Very detailed</source>
        <translation>Très détaillé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Detailed (default setting)</source>
        <translation>Détaillé (réglage par défaut)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Limited</source>
        <translation>Limité</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Display log</source>
        <translation>Afficher le journal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Still running</source>
        <translation>Opération toujours en cours</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installation de l&apos;écran d&apos;amorçage, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Updating sources</source>
        <translation>Mise-à-jour des sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <source>Installing</source>
        <translation>Installation en cours</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Could not install the bootsplash.</source>
        <translation>L&apos;écran d&apos;amorçage n&apos;a pas pu être installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Cannot continue</source>
        <translation>Impossible de continuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Aucun choix sélectionné, aucune modification des options de démarrage. Sortie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Could not create a temporary folder</source>
        <translation>Impossible de créer un dossier temporaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Impossible de créer environnement chroot, impossible de modifier les options de démarrage. Sortie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Updating configuration, please wait</source>
        <translation>Mise-à-jour de la configuration, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Updating initramfs...</source>
        <translation>Mise-à-jour de initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Updating grub...</source>
        <translation>Mise-à-jour de grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Changes have been successfully applied.</source>
        <translation>Toutes les modifications ont été appliquées avec succès.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="658"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>MX Boot Options</source>
        <translation>MX Options de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="716"/>
        <source>Running in a Virtual Machine</source>
        <translation>Lancer dans une machine virtuelle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="717"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Votre système actuel fonctionne dans une Machine Virtuelle,
L&apos;écran d&apos;amorçage Plymouth fonctionnera de façon restreinte, vous ne pourrez pas non plus prévisualiser le thème</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages not installed</source>
        <translation>Les paquets pour Plymouth ne sont pas installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Les paquets Plymouth ne sont pas installés actuellement.
OK pour continuer et les installer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Images (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>Press any key to close</source>
        <translation>Appuyez sur une touche pour fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Log not found</source>
        <translation>Log introuvable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Could not find log at </source>
        <translation>N&apos;a pas pu trouver de journal à</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Needs reboot</source>
        <translation>Redémarrage requis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth vient d&apos;être installé, vous devrez probablement redémarrer avant de pouvoir afficher les aperçus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <source>Click to select theme</source>
        <translation>Cliquez pour sélectionner le thème</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous semblez être connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu&apos;utilisateur normal pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>Select image to display in bootloader</source>
        <translation>Choisissez l&apos;image à afficher pour le chargeur de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Select GRUB theme</source>
        <translation>Sélectionnez le thème de GRUB</translation>
    </message>
</context>
</TS>
